@@ -1,6 +1,8 @@
+import hashlib
 import logging
 import time
 import uuid
+from contextlib import suppress
 from datetime import timedelta
 from urllib.parse import parse_qsl, urlparse
 
@@ -8,7 +10,7 @@ from django.apps import apps
 from django.conf import settings
 from django.contrib.auth.hashers import identify_hasher, make_password
 from django.core.exceptions import ImproperlyConfigured
-from django.db import models, transaction
+from django.db import models, router, transaction
 from django.urls import reverse
 from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
@@ -44,6 +46,14 @@ class ClientSecretField(models.CharField):
         return super().pre_save(model_instance, add)
 
 
+class TokenChecksumField(models.CharField):
+    def pre_save(self, model_instance, add):
+        token = getattr(model_instance, "token")
+        checksum = hashlib.sha256(token.encode("utf-8")).hexdigest()
+        setattr(model_instance, self.attname, checksum)
+        return super().pre_save(model_instance, add)
+
+
 class AbstractApplication(models.Model):
     """
     An Application instance represents a Client on the Authorization server.
@@ -235,7 +245,7 @@ class AbstractApplication(models.Model):
                 raise ValidationError(_("You cannot use HS256 with public grants or clients"))
 
     def get_absolute_url(self):
-        return reverse("oauth2_provider:detail", args=[str(self.id)])
+        return reverse("oauth2_provider:detail", args=[str(self.pk)])
 
     def get_allowed_schemes(self):
         """
@@ -379,8 +389,10 @@ class AbstractAccessToken(models.Model):
         null=True,
         related_name="refreshed_access_token",
     )
-    token = models.CharField(
-        max_length=255,
+    token = models.TextField()
+    token_checksum = TokenChecksumField(
+        max_length=64,
+        blank=False,
         unique=True,
         db_index=True,
     )
@@ -490,6 +502,7 @@ class AbstractRefreshToken(models.Model):
         null=True,
         related_name="refresh_token",
     )
+    token_family = models.UUIDField(null=True, blank=True, editable=False)
 
     created = models.DateTimeField(auto_now_add=True)
     updated = models.DateTimeField(auto_now=True)
@@ -500,17 +513,19 @@ class AbstractRefreshToken(models.Model):
         Mark this refresh token revoked and revoke related access token
         """
         access_token_model = get_access_token_model()
+        access_token_database = router.db_for_write(access_token_model)
         refresh_token_model = get_refresh_token_model()
-        with transaction.atomic():
+
+        # Use the access_token_database instead of making the assumption it is in 'default'.
+        with transaction.atomic(using=access_token_database):
             token = refresh_token_model.objects.select_for_update().filter(pk=self.pk, revoked__isnull=True)
             if not token:
                 return
             self = list(token)[0]
 
-            try:
+            with suppress(access_token_model.DoesNotExist):
                 access_token_model.objects.get(id=self.access_token_id).revoke()
-            except access_token_model.DoesNotExist:
-                pass
+
             self.access_token = None
             self.revoked = timezone.now()
             self.save()
@@ -643,7 +658,7 @@ def get_access_token_model():
 
 
 def get_id_token_model():
-    """Return the AccessToken model that is active in this project."""
+    """Return the IDToken model that is active in this project."""
     return apps.get_model(oauth2_settings.ID_TOKEN_MODEL)
 
 
