@@ -1,15 +1,18 @@
 import calendar
+import hashlib
 
 from django.core.exceptions import ObjectDoesNotExist
 from django.http import JsonResponse
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 
-from oauth2_provider.models import get_access_token_model
-from oauth2_provider.views.generic import ClientProtectedScopedResourceView
+from ..compat import login_not_required
+from ..models import get_access_token_model
+from ..views.generic import ClientProtectedScopedResourceView
 
 
 @method_decorator(csrf_exempt, name="dispatch")
+@method_decorator(login_not_required, name="dispatch")
 class IntrospectTokenView(ClientProtectedScopedResourceView):
     """
     Implements an endpoint for token introspection based
@@ -24,8 +27,11 @@ class IntrospectTokenView(ClientProtectedScopedResourceView):
     @staticmethod
     def get_token_response(token_value=None):
         try:
+            token_checksum = hashlib.sha256(token_value.encode("utf-8")).hexdigest()
             token = (
-                get_access_token_model().objects.select_related("user", "application").get(token=token_value)
+                get_access_token_model()
+                .objects.select_related("user", "application")
+                .get(token_checksum=token_checksum)
             )
         except ObjectDoesNotExist:
             return JsonResponse({"active": False}, status=200)
