@@ -1,5 +1,4 @@
 import json
-import warnings
 from urllib.parse import urlparse
 
 from django.contrib.auth import logout
@@ -15,6 +14,7 @@ from jwcrypto.jws import InvalidJWSObject
 from jwcrypto.jwt import JWTExpired
 from oauthlib.common import add_params_to_uri
 
+from ..compat import login_not_required
 from ..exceptions import (
     ClientIdMissmatch,
     InvalidIDTokenError,
@@ -40,6 +40,7 @@ from .mixins import OAuthLibMixin, OIDCLogoutOnlyMixin, OIDCOnlyMixin
 Application = get_application_model()
 
 
+@method_decorator(login_not_required, name="dispatch")
 class ConnectDiscoveryInfoView(OIDCOnlyMixin, View):
     """
     View used to show oidc provider configuration information per
@@ -107,6 +108,7 @@ class ConnectDiscoveryInfoView(OIDCOnlyMixin, View):
         return response
 
 
+@method_decorator(login_not_required, name="dispatch")
 class JwksInfoView(OIDCOnlyMixin, View):
     """
     View used to show oidc json web key set document
@@ -135,6 +137,7 @@ class JwksInfoView(OIDCOnlyMixin, View):
 
 
 @method_decorator(csrf_exempt, name="dispatch")
+@method_decorator(login_not_required, name="dispatch")
 class UserInfoView(OIDCOnlyMixin, OAuthLibMixin, View):
     """
     View used to show Claims about the authenticated End-User
@@ -212,76 +215,7 @@ def _validate_claims(request, claims):
     return True
 
 
-def validate_logout_request(request, id_token_hint, client_id, post_logout_redirect_uri):
-    """
-    Validate an OIDC RP-Initiated Logout Request.
-    `(prompt_logout, (post_logout_redirect_uri, application), token_user)` is returned.
-
-    `prompt_logout` indicates whether the logout has to be confirmed by the user. This happens if the
-    specifications force a confirmation, or it is enabled by `OIDC_RP_INITIATED_LOGOUT_ALWAYS_PROMPT`.
-    `post_logout_redirect_uri` is the validated URI where the User should be redirected to after the
-    logout. Can be None. None will redirect to "/" of this app. If it is set `application` will also
-    be set to the Application that is requesting the logout. `token_user` is the id_token user, which will
-    used to revoke the tokens if found.
-
-    The `id_token_hint` will be validated if given. If both `client_id` and `id_token_hint` are given they
-    will be validated against each other.
-    """
-
-    warnings.warn("This method is deprecated and will be removed in version 2.5.0.", DeprecationWarning)
-
-    id_token = None
-    must_prompt_logout = True
-    token_user = None
-    if id_token_hint:
-        # Only basic validation has been done on the IDToken at this point.
-        id_token, claims = _load_id_token(id_token_hint)
-
-        if not id_token or not _validate_claims(request, claims):
-            raise InvalidIDTokenError()
-
-        token_user = id_token.user
-
-        if id_token.user == request.user:
-            # A logout without user interaction (i.e. no prompt) is only allowed
-            # if an ID Token is provided that matches the current user.
-            must_prompt_logout = False
-
-        # If both id_token_hint and client_id are given it must be verified that they match.
-        if client_id:
-            if id_token.application.client_id != client_id:
-                raise ClientIdMissmatch()
-
-    # The standard states that a prompt should always be shown.
-    # This behaviour can be configured with OIDC_RP_INITIATED_LOGOUT_ALWAYS_PROMPT.
-    prompt_logout = must_prompt_logout or oauth2_settings.OIDC_RP_INITIATED_LOGOUT_ALWAYS_PROMPT
-
-    application = None
-    # Determine the application that is requesting the logout.
-    if client_id:
-        application = get_application_model().objects.get(client_id=client_id)
-    elif id_token:
-        application = id_token.application
-
-    # Validate `post_logout_redirect_uri`
-    if post_logout_redirect_uri:
-        if not application:
-            raise InvalidOIDCClientError()
-        scheme = urlparse(post_logout_redirect_uri)[0]
-        if not scheme:
-            raise InvalidOIDCRedirectURIError("A Scheme is required for the redirect URI.")
-        if oauth2_settings.OIDC_RP_INITIATED_LOGOUT_STRICT_REDIRECT_URIS and (
-            scheme == "http" and application.client_type != "confidential"
-        ):
-            raise InvalidOIDCRedirectURIError("http is only allowed with confidential clients.")
-        if scheme not in application.get_allowed_schemes():
-            raise InvalidOIDCRedirectURIError(f'Redirect to scheme "{scheme}" is not permitted.')
-        if not application.post_logout_redirect_uri_allowed(post_logout_redirect_uri):
-            raise InvalidOIDCRedirectURIError("This client does not have this redirect uri registered.")
-
-    return prompt_logout, (post_logout_redirect_uri, application), token_user
-
-
+@method_decorator(login_not_required, name="dispatch")
 class RPInitiatedLogoutView(OIDCLogoutOnlyMixin, FormView):
     template_name = "oauth2_provider/logout_confirm.html"
     form_class = ConfirmLogoutForm
