@@ -1,3 +1,6 @@
+import django
+
+
 ADMINS = ()
 
 MANAGERS = ADMINS
@@ -23,7 +26,8 @@ LANGUAGE_CODE = "en-us"
 SITE_ID = 1
 
 USE_I18N = True
-USE_L10N = True
+if django.VERSION < (4, 0):
+    USE_L10N = True
 USE_TZ = True
 
 MEDIA_ROOT = ""
@@ -54,6 +58,7 @@ TEMPLATES = [
                 "django.template.context_processors.debug",
                 "django.template.context_processors.i18n",
                 "django.template.context_processors.media",
+                "django.template.context_processors.request",
                 "django.template.context_processors.static",
                 "django.template.context_processors.tz",
                 "django.contrib.messages.context_processors.messages",
@@ -159,3 +164,4 @@ OAUTH2_PROVIDER_ID_TOKEN_MODEL = "oauth2_provider.IDToken"
 
 CLEAR_EXPIRED_TOKENS_BATCH_SIZE = 1
 CLEAR_EXPIRED_TOKENS_BATCH_INTERVAL = 0
+PKCE_REQUIRED = False
