@@ -5,7 +5,7 @@ from django.contrib.auth import get_user_model
 from django.contrib.auth.models import AnonymousUser
 from django.core.exceptions import SuspiciousOperation
 from django.http import HttpResponse
-from django.test import RequestFactory, TestCase
+from django.test import RequestFactory
 from django.test.utils import modify_settings, override_settings
 from django.utils.timezone import now, timedelta
 
@@ -13,6 +13,8 @@ from oauth2_provider.backends import OAuth2Backend
 from oauth2_provider.middleware import OAuth2ExtraTokenMiddleware, OAuth2TokenMiddleware
 from oauth2_provider.models import get_access_token_model, get_application_model
 
+from .common_testing import OAuth2ProviderTestCase as TestCase
+
 
 UserModel = get_user_model()
 ApplicationModel = get_application_model()
