@@ -6,17 +6,19 @@ from django.conf import settings
 from django.conf.urls import include
 from django.contrib.auth import get_user_model
 from django.http import HttpResponse
-from django.test import TestCase, override_settings
+from django.test import override_settings
 from django.urls import path
 from django.utils import timezone
 from oauthlib.common import Request
 
+from oauth2_provider.compat import login_not_required
 from oauth2_provider.models import get_access_token_model, get_application_model
 from oauth2_provider.oauth2_validators import OAuth2Validator
 from oauth2_provider.settings import oauth2_settings
 from oauth2_provider.views import ScopedProtectedResourceView
 
 from . import presets
+from .common_testing import OAuth2ProviderTestCase as TestCase
 
 
 try:
@@ -93,7 +95,7 @@ def mocked_introspect_request_short_living_token(url, data, *args, **kwargs):
 
 urlpatterns = [
     path("oauth2/", include("oauth2_provider.urls")),
-    path("oauth2-test-resource/", ScopeResourceView.as_view()),
+    path("oauth2-test-resource/", login_not_required(ScopeResourceView.as_view())),
 ]
 
 
