@@ -3,7 +3,7 @@ import logging
 import pytest
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpResponse
-from django.test import RequestFactory, TestCase
+from django.test import RequestFactory
 from django.views.generic import View
 from oauthlib.oauth2 import Server
 
@@ -18,6 +18,7 @@ from oauth2_provider.views.mixins import (
 )
 
 from . import presets
+from .common_testing import OAuth2ProviderTestCase as TestCase
 
 
 @pytest.mark.usefixtures("oauth2_settings")
