@@ -1,10 +1,11 @@
+import hashlib
+import secrets
 from datetime import timedelta
 
 import pytest
 from django.contrib.auth import get_user_model
 from django.contrib.auth.hashers import check_password
 from django.core.exceptions import ImproperlyConfigured, ValidationError
-from django.test import TestCase
 from django.test.utils import override_settings
 from django.utils import timezone
 
@@ -18,6 +19,8 @@ from oauth2_provider.models import (
 )
 
 from . import presets
+from .common_testing import OAuth2ProviderTestCase as TestCase
+from .common_testing import retrieve_current_databases
 
 
 CLEARTEXT_SECRET = "1234567890abcdefghijklmnopqrstuvwxyz"
@@ -310,6 +313,17 @@ class TestAccessTokenModel(BaseTestModels):
         self.assertIsNone(access_token.expires)
         self.assertTrue(access_token.is_expired())
 
+    def test_token_checksum_field(self):
+        token = secrets.token_urlsafe(32)
+        access_token = AccessToken.objects.create(
+            user=self.user,
+            token=token,
+            expires=timezone.now() + timedelta(hours=1),
+        )
+        expected_checksum = hashlib.sha256(token.encode()).hexdigest()
+
+        self.assertEqual(access_token.token_checksum, expected_checksum)
+
 
 class TestRefreshTokenModel(BaseTestModels):
     def test_str(self):
@@ -453,7 +467,7 @@ class TestClearExpired(BaseTestModels):
         assert remaining_gt_count == initial_gt_count // 2, "half the remaining grants should still exist."
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(databases=retrieve_current_databases())
 @pytest.mark.oauth2_settings(presets.OIDC_SETTINGS_RW)
 def test_id_token_methods(oidc_tokens, rf):
     id_token = IDToken.objects.get()
@@ -488,7 +502,7 @@ def test_id_token_methods(oidc_tokens, rf):
     assert IDToken.objects.filter(jti=id_token.jti).count() == 0
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(databases=retrieve_current_databases())
 @pytest.mark.oauth2_settings(presets.OIDC_SETTINGS_RW)
 def test_clear_expired_id_tokens(oauth2_settings, oidc_tokens, rf):
     id_token = IDToken.objects.get()
@@ -527,7 +541,7 @@ def test_clear_expired_id_tokens(oauth2_settings, oidc_tokens, rf):
     assert not IDToken.objects.filter(jti=id_token.jti).exists()
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(databases=retrieve_current_databases())
 @pytest.mark.oauth2_settings(presets.OIDC_SETTINGS_RW)
 def test_application_key(oauth2_settings, application):
     # RS256 key
@@ -552,7 +566,7 @@ def test_application_key(oauth2_settings, application):
     assert "This application does not support signed tokens" == str(exc.value)
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(databases=retrieve_current_databases())
 @pytest.mark.oauth2_settings(presets.OIDC_SETTINGS_RW)
 def test_application_clean(oauth2_settings, application):
     # RS256, RSA key is configured
@@ -592,7 +606,7 @@ def test_application_clean(oauth2_settings, application):
     application.clean()
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(databases=retrieve_current_databases())
 @pytest.mark.oauth2_settings(presets.ALLOWED_SCHEMES_DEFAULT)
 def test_application_origin_allowed_default_https(oauth2_settings, cors_application):
     """Test that http schemes are not allowed because ALLOWED_SCHEMES allows only https"""
@@ -600,7 +614,7 @@ def test_application_origin_allowed_default_https(oauth2_settings, cors_applicat
     assert not cors_application.origin_allowed("http://example.com")
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(databases=retrieve_current_databases())
 @pytest.mark.oauth2_settings(presets.ALLOWED_SCHEMES_HTTP)
 def test_application_origin_allowed_http(oauth2_settings, cors_application):
     """Test that http schemes are allowed because http was added to ALLOWED_SCHEMES"""
