@@ -1,11 +1,13 @@
 from django.contrib import admin
 from django.urls import include, path
 
+from oauth2_provider import urls as oauth2_urls
+
 
 admin.autodiscover()
 
 
 urlpatterns = [
-    path("o/", include("oauth2_provider.urls", namespace="oauth2_provider")),
+    path("o/", include(oauth2_urls)),
     path("admin/", admin.site.urls),
 ]
